@@ -1,5 +1,5 @@
 //
-// Copyright (C) 1999-2004 Toshikaz Hirabayashi
+// Copyright (C) 1999-2004 WideStudio Development Team
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to
@@ -14,22 +14,301 @@
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
-// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 // SOFTWARE.
-// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
-// not be used in advertising or otherwise to promote the sale, use or other
-// dealings in this Software without prior written authorization from
-// Toshikaz Hirabayashi.
+// Except as contained in this notice, the name of WideStudio Development Team
+// shall not be used in advertising or otherwise to promote the sale, use or
+// other dealings in this Software without prior written authorization from
+// WideStudio Development Team.
 
 #ifndef WSKEYSYM_H
 #define WSKEYSYM_H
 
+//-----------------------------------------------------------------------------
+#if (defined USE_FB) || (defined USE_X11)
+//-----------------------------------------------------------------------------
+
+#define XK_BackSpace    0xFF08
+#define XK_Tab          0xFF09
+#define XK_Linefeed     0xFF0A
+#define XK_Clear        0xFF0B
+#define XK_Return       0xFF0D
+#define XK_Pause        0xFF13
+#define XK_Scroll_Lock  0xFF14
+#define XK_Sys_Req      0xFF15
+#define XK_Escape       0xFF1B
+#define XK_Delete       0xFFFF
+
+#define XK_Kanji        0xFF21
+#define XK_Muhenkan     0xFF22
+#define XK_Henkan_Mode  0xFF23
+#define XK_Henkan       0xFF23
+#define XK_Romaji       0xFF24
+#define XK_Hiragana     0xFF25
+#define XK_Katakana     0xFF26
+#define XK_Hiragana_Katakana  0xFF27
+#define XK_Zenkaku      0xFF28
+#define XK_Hankaku      0xFF29
+#define XK_Zenkaku_Hankaku  0xFF2A
+#define XK_Touroku      0xFF2B
+#define XK_Massyo       0xFF2C
+#define XK_Kana_Lock    0xFF2D
+#define XK_Kana_Shift   0xFF2E
+#define XK_Eisu_Shift   0xFF2F
+#define XK_Eisu_toggle  0xFF30
+
+#define XK_Home         0xFF50
+#define XK_Left         0xFF51
+#define XK_Up           0xFF52
+#define XK_Right        0xFF53
+#define XK_Down         0xFF54
+#define XK_Prior        0xFF55
+#define XK_Page_Up      0xFF55
+#define XK_Next         0xFF56
+#define XK_Page_Down    0xFF56
+#define XK_End          0xFF57
+#define XK_Begin        0xFF58
+
+#define XK_Select       0xFF60
+#define XK_Print        0xFF61
+#define XK_Execute      0xFF62
+#define XK_Insert       0xFF63
+#define XK_Undo         0xFF65
+#define XK_Redo         0xFF66
+#define XK_Menu         0xFF67
+#define XK_Find         0xFF68
+#define XK_Cancel       0xFF69
+#define XK_Help         0xFF6A
+#define XK_Break        0xFF6B
+#define XK_Mode_switch  0xFF7E
+#define XK_script_switch 0xFF7E
+#define XK_Num_Lock     0xFF7F
+
+#define XK_KP_Space     0xFF80
+#define XK_KP_Tab       0xFF89
+#define XK_KP_Enter     0xFF8D
+#define XK_KP_F1        0xFF91
+#define XK_KP_F2        0xFF92
+#define XK_KP_F3        0xFF93
+#define XK_KP_F4        0xFF94
+#define XK_KP_Home      0xFF95
+#define XK_KP_Left      0xFF96
+#define XK_KP_Up        0xFF97
+#define XK_KP_Right     0xFF98
+#define XK_KP_Down      0xFF99
+#define XK_KP_Prior     0xFF9A
+#define XK_KP_Page_Up   0xFF9A
+#define XK_KP_Next      0xFF9B
+#define XK_KP_Page_Down 0xFF9B
+#define XK_KP_End       0xFF9C
+#define XK_KP_Begin     0xFF9D
+#define XK_KP_Insert    0xFF9E
+#define XK_KP_Delete    0xFF9F
+#define XK_KP_Equal     0xFFBD
+#define XK_KP_Multiply  0xFFAA
+#define XK_KP_Add       0xFFAB
+#define XK_KP_Separator 0xFFAC
+#define XK_KP_Subtract  0xFFAD
+#define XK_KP_Decimal   0xFFAE
+#define XK_KP_Divide    0xFFAF
+
+#define XK_KP_0         0xFFB0
+#define XK_KP_1         0xFFB1
+#define XK_KP_2         0xFFB2
+#define XK_KP_3         0xFFB3
+#define XK_KP_4         0xFFB4
+#define XK_KP_5         0xFFB5
+#define XK_KP_6         0xFFB6
+#define XK_KP_7         0xFFB7
+#define XK_KP_8         0xFFB8
+#define XK_KP_9         0xFFB9
+
+#define XK_F1           0xFFBE
+#define XK_F2           0xFFBF
+#define XK_F3           0xFFC0
+#define XK_F4           0xFFC1
+#define XK_F5           0xFFC2
+#define XK_F6           0xFFC3
+#define XK_F7           0xFFC4
+#define XK_F8           0xFFC5
+#define XK_F9           0xFFC6
+#define XK_F10          0xFFC7
+#define XK_F11          0xFFC8
+#define XK_L1           0xFFC8
+#define XK_F12          0xFFC9
+#define XK_L2           0xFFC9
+#define XK_F13          0xFFCA
+#define XK_L3           0xFFCA
+#define XK_F14          0xFFCB
+#define XK_L4           0xFFCB
+#define XK_F15          0xFFCC
+#define XK_L5           0xFFCC
+#define XK_F16          0xFFCD
+#define XK_L6           0xFFCD
+#define XK_F17          0xFFCE
+#define XK_L7           0xFFCE
+#define XK_F18          0xFFCF
+#define XK_L8           0xFFCF
+#define XK_F19          0xFFD0
+#define XK_L9           0xFFD0
+#define XK_F20          0xFFD1
+#define XK_L10          0xFFD1
+#define XK_F21          0xFFD2
+#define XK_R1           0xFFD2
+#define XK_F22          0xFFD3
+#define XK_R2           0xFFD3
+#define XK_F23          0xFFD4
+#define XK_R3           0xFFD4
+#define XK_F24          0xFFD5
+#define XK_R4           0xFFD5
+#define XK_F25          0xFFD6
+#define XK_R5           0xFFD6
+#define XK_F26          0xFFD7
+#define XK_R6           0xFFD7
+#define XK_F27          0xFFD8
+#define XK_R7           0xFFD8
+#define XK_F28          0xFFD9
+#define XK_R8           0xFFD9
+#define XK_F29          0xFFDA
+#define XK_R9           0xFFDA
+#define XK_F30          0xFFDB
+#define XK_R10          0xFFDB
+#define XK_F31          0xFFDC
+#define XK_R11          0xFFDC
+#define XK_F32          0xFFDD
+#define XK_R12          0xFFDD
+#define XK_F33          0xFFDE
+#define XK_R13          0xFFDE
+#define XK_F34          0xFFDF
+#define XK_R14          0xFFDF
+#define XK_F35          0xFFE0
+#define XK_R15          0xFFE0
+
+#define XK_Shift_L      0xFFE1
+#define XK_Shift_R      0xFFE2
+#define XK_Control_L    0xFFE3
+#define XK_Control_R    0xFFE4
+#define XK_Caps_Lock    0xFFE5
+#define XK_Shift_Lock   0xFFE6
+
+#define XK_Meta_L       0xFFE7
+#define XK_Meta_R       0xFFE8
+#define XK_Alt_L        0xFFE9
+#define XK_Alt_R        0xFFEA
+#define XK_Super_L      0xFFEB
+#define XK_Super_R      0xFFEC
+#define XK_Hyper_L      0xFFED
+#define XK_Hyper_R      0xFFEE
+
+#define XK_space               0x020
+#define XK_exclam              0x021
+#define XK_quotedbl            0x022
+#define XK_numbersign          0x023
+#define XK_dollar              0x024
+#define XK_percent             0x025
+#define XK_ampersand           0x026
+#define XK_apostrophe          0x027
+#define XK_quoteright          0x027    /* deprecated */
+#define XK_parenleft           0x028
+#define XK_parenright          0x029
+#define XK_asterisk            0x02a
+#define XK_plus                0x02b
+#define XK_comma               0x02c
+#define XK_minus               0x02d
+#define XK_period              0x02e
+#define XK_slash               0x02f
+#define XK_0                   0x030
+#define XK_1                   0x031
+#define XK_2                   0x032
+#define XK_3                   0x033
+#define XK_4                   0x034
+#define XK_5                   0x035
+#define XK_6                   0x036
+#define XK_7                   0x037
+#define XK_8                   0x038
+#define XK_9                   0x039
+#define XK_colon               0x03a
+#define XK_semicolon           0x03b
+#define XK_less                0x03c
+#define XK_equal               0x03d
+#define XK_greater             0x03e
+#define XK_question            0x03f
+#define XK_at                  0x040
+#define XK_A                   0x041
+#define XK_B                   0x042
+#define XK_C                   0x043
+#define XK_D                   0x044
+#define XK_E                   0x045
+#define XK_F                   0x046
+#define XK_G                   0x047
+#define XK_H                   0x048
+#define XK_I                   0x049
+#define XK_J                   0x04a
+#define XK_K                   0x04b
+#define XK_L                   0x04c
+#define XK_M                   0x04d
+#define XK_N                   0x04e
+#define XK_O                   0x04f
+#define XK_P                   0x050
+#define XK_Q                   0x051
+#define XK_R                   0x052
+#define XK_S                   0x053
+#define XK_T                   0x054
+#define XK_U                   0x055
+#define XK_V                   0x056
+#define XK_W                   0x057
+#define XK_X                   0x058
+#define XK_Y                   0x059
+#define XK_Z                   0x05a
+#define XK_bracketleft         0x05b
+#define XK_backslash           0x05c
+#define XK_bracketright        0x05d
+#define XK_asciicircum         0x05e
+#define XK_underscore          0x05f
+#define XK_grave               0x060
+#define XK_quoteleft           0x060    /* deprecated */
+#define XK_a                   0x061
+#define XK_b                   0x062
+#define XK_c                   0x063
+#define XK_d                   0x064
+#define XK_e                   0x065
+#define XK_f                   0x066
+#define XK_g                   0x067
+#define XK_h                   0x068
+#define XK_i                   0x069
+#define XK_j                   0x06a
+#define XK_k                   0x06b
+#define XK_l                   0x06c
+#define XK_m                   0x06d
+#define XK_n                   0x06e
+#define XK_o                   0x06f
+#define XK_p                   0x070
+#define XK_q                   0x071
+#define XK_r                   0x072
+#define XK_s                   0x073
+#define XK_t                   0x074
+#define XK_u                   0x075
+#define XK_v                   0x076
+#define XK_w                   0x077
+#define XK_x                   0x078
+#define XK_y                   0x079
+#define XK_z                   0x07a
+#define XK_braceleft           0x07b
+#define XK_bar                 0x07c
+#define XK_braceright          0x07d
+#define XK_asciitilde          0x07e
+
+#endif
+//-----------------------------------------------------------------------------
+
 //-----------------------------------------------------------------------------
 #if !defined MSW  && !defined BTRON //UNIX - Xwindow System
 //-----------------------------------------------------------------------------
+#ifndef USE_FB
 #include <X11/keysym.h>
+#endif
 #define WSK_BackSpace   XK_BackSpace
 #define WSK_Tab         XK_Tab
 #define WSK_Linefeed    XK_Linefeed
@@ -302,6 +581,104 @@
 #define WSK_braceright          XK_braceright
 #define WSK_asciitilde          XK_asciitilde
 
+#define WSK_nobreakspace        0x0a0
+#define WSK_exclamdown          0x0a1
+#define WSK_cent                0x0a2
+#define WSK_sterling            0x0a3
+#define WSK_currency            0x0a4
+#define WSK_yen                 0x0a5
+#define WSK_brokenbar           0x0a6
+#define WSK_section             0x0a7
+#define WSK_diaeresis           0x0a8
+#define WSK_copyright           0x0a9
+#define WSK_ordfeminine         0x0aa
+#define WSK_guillemotleft       0x0ab
+#define WSK_notsign             0x0ac
+#define WSK_hyphen              0x0ad
+#define WSK_registered          0x0ae
+#define WSK_macron              0x0af
+#define WSK_degree              0x0b0
+#define WSK_plusminus           0x0b1
+#define WSK_twosuperior         0x0b2
+#define WSK_threesuperior       0x0b3
+#define WSK_acute               0x0b4
+#define WSK_mu                  0x0b5
+#define WSK_paragraph           0x0b6
+#define WSK_periodcentered      0x0b7
+#define WSK_cedilla             0x0b8
+#define WSK_onesuperior         0x0b9
+#define WSK_masculine           0x0ba
+#define WSK_guillemotright      0x0bb
+#define WSK_onequarter          0x0bc
+#define WSK_onehalf             0x0bd
+#define WSK_threequarters       0x0be
+#define WSK_questiondown        0x0bf
+#define WSK_Agrave              0x0c0
+#define WSK_Aacute              0x0c1
+#define WSK_Acircumflex         0x0c2
+#define WSK_Atilde              0x0c3
+#define WSK_Adiaeresis          0x0c4
+#define WSK_Aring               0x0c5
+#define WSK_AE                  0x0c6
+#define WSK_Ccedilla            0x0c7
+#define WSK_Egrave              0x0c8
+#define WSK_Eacute              0x0c9
+#define WSK_Ecircumflex         0x0ca
+#define WSK_Ediaeresis          0x0cb
+#define WSK_Igrave              0x0cc
+#define WSK_Iacute              0x0cd
+#define WSK_Icircumflex         0x0ce
+#define WSK_Idiaeresis          0x0cf
+#define WSK_Eth                 0x0d0
+#define WSK_Ntilde              0x0d1
+#define WSK_Ograve              0x0d2
+#define WSK_Oacute              0x0d3
+#define WSK_Ocircumflex         0x0d4
+#define WSK_Otilde              0x0d5
+#define WSK_Odiaeresis          0x0d6
+#define WSK_multiply            0x0d7
+#define WSK_Ooblique            0x0d8
+#define WSK_Ugrave              0x0d9
+#define WSK_Uacute              0x0da
+#define WSK_Ucircumflex         0x0db
+#define WSK_Udiaeresis          0x0dc
+#define WSK_Yacute              0x0dd
+#define WSK_Thorn               0x0de
+#define WSK_ssharp              0x0df
+#define WSK_agrave              0x0e0
+#define WSK_aacute              0x0e1
+#define WSK_acircumflex         0x0e2
+#define WSK_atilde              0x0e3
+#define WSK_adiaeresis          0x0e4
+#define WSK_aring               0x0e5
+#define WSK_ae                  0x0e6
+#define WSK_ccedilla            0x0e7
+#define WSK_egrave              0x0e8
+#define WSK_eacute              0x0e9
+#define WSK_ecircumflex         0x0ea
+#define WSK_ediaeresis          0x0eb
+#define WSK_igrave              0x0ec
+#define WSK_iacute              0x0ed
+#define WSK_icircumflex         0x0ee
+#define WSK_idiaeresis          0x0ef
+#define WSK_eth                 0x0f0
+#define WSK_ntilde              0x0f1
+#define WSK_ograve              0x0f2
+#define WSK_oacute              0x0f3
+#define WSK_ocircumflex         0x0f4
+#define WSK_otilde              0x0f5
+#define WSK_odiaeresis          0x0f6
+#define WSK_division            0x0f7
+#define WSK_oslash              0x0f8
+#define WSK_ugrave              0x0f9
+#define WSK_uacute              0x0fa
+#define WSK_ucircumflex         0x0fb
+#define WSK_udiaeresis          0x0fc
+#define WSK_yacute              0x0fd
+#define WSK_thorn               0x0fe
+#define WSK_ydiaeresis          0x0ff
+
+
 #endif //UNIX - Xwindow System
 
 //-----------------------------------------------------------------------------
@@ -584,6 +961,104 @@
 #define WSK_braceright			0x17d
 #define WSK_asciitilde			0x17e
 
+#define WSK_nobreakspace        0x1a0
+#define WSK_exclamdown          0x1a1
+#define WSK_cent                0x1a2
+#define WSK_sterling            0x1a3
+#define WSK_currency            0x1a4
+#define WSK_yen                 0x1a5
+#define WSK_brokenbar           0x1a6
+#define WSK_section             0x1a7
+#define WSK_diaeresis           0x1a8
+#define WSK_copyright           0x1a9
+#define WSK_ordfeminine         0x1aa
+#define WSK_guillemotleft       0x1ab
+#define WSK_notsign             0x1ac
+#define WSK_hyphen              0x1ad
+#define WSK_registered          0x1ae
+#define WSK_macron              0x1af
+#define WSK_degree              0x1b0
+#define WSK_plusminus           0x1b1
+#define WSK_twosuperior         0x1b2
+#define WSK_threesuperior       0x1b3
+#define WSK_acute               0x1b4
+#define WSK_mu                  0x1b5
+#define WSK_paragraph           0x1b6
+#define WSK_periodcentered      0x1b7
+#define WSK_cedilla             0x1b8
+#define WSK_onesuperior         0x1b9
+#define WSK_masculine           0x1ba
+#define WSK_guillemotright      0x1bb
+#define WSK_onequarter          0x1bc
+#define WSK_onehalf             0x1bd
+#define WSK_threequarters       0x1be
+#define WSK_questiondown        0x1bf
+#define WSK_Agrave              0x1c0
+#define WSK_Aacute              0x1c1
+#define WSK_Acircumflex         0x1c2
+#define WSK_Atilde              0x1c3
+#define WSK_Adiaeresis          0x1c4
+#define WSK_Aring               0x1c5
+#define WSK_AE                  0x1c6
+#define WSK_Ccedilla            0x1c7
+#define WSK_Egrave              0x1c8
+#define WSK_Eacute              0x1c9
+#define WSK_Ecircumflex         0x1ca
+#define WSK_Ediaeresis          0x1cb
+#define WSK_Igrave              0x1cc
+#define WSK_Iacute              0x1cd
+#define WSK_Icircumflex         0x1ce
+#define WSK_Idiaeresis          0x1cf
+#define WSK_Eth                 0x1d0
+#define WSK_Ntilde              0x1d1
+#define WSK_Ograve              0x1d2
+#define WSK_Oacute              0x1d3
+#define WSK_Ocircumflex         0x1d4
+#define WSK_Otilde              0x1d5
+#define WSK_Odiaeresis          0x1d6
+#define WSK_multiply            0x1d7
+#define WSK_Ooblique            0x1d8
+#define WSK_Ugrave              0x1d9
+#define WSK_Uacute              0x1da
+#define WSK_Ucircumflex         0x1db
+#define WSK_Udiaeresis          0x1dc
+#define WSK_Yacute              0x1dd
+#define WSK_Thorn               0x1de
+#define WSK_ssharp              0x1df
+#define WSK_agrave              0x1e0
+#define WSK_aacute              0x1e1
+#define WSK_acircumflex         0x1e2
+#define WSK_atilde              0x1e3
+#define WSK_adiaeresis          0x1e4
+#define WSK_aring               0x1e5
+#define WSK_ae                  0x1e6
+#define WSK_ccedilla            0x1e7
+#define WSK_egrave              0x1e8
+#define WSK_eacute              0x1e9
+#define WSK_ecircumflex         0x1ea
+#define WSK_ediaeresis          0x1eb
+#define WSK_igrave              0x1ec
+#define WSK_iacute              0x1ed
+#define WSK_icircumflex         0x1ee
+#define WSK_idiaeresis          0x1ef
+#define WSK_eth                 0x1f0
+#define WSK_ntilde              0x1f1
+#define WSK_ograve              0x1f2
+#define WSK_oacute              0x1f3
+#define WSK_ocircumflex         0x1f4
+#define WSK_otilde              0x1f5
+#define WSK_odiaeresis          0x1f6
+#define WSK_division            0x1f7
+#define WSK_oslash              0x1f8
+#define WSK_ugrave              0x1f9
+#define WSK_uacute              0x1fa
+#define WSK_ucircumflex         0x1fb
+#define WSK_udiaeresis          0x1fc
+#define WSK_yacute              0x1fd
+#define WSK_thorn               0x1fe
+#define WSK_ydiaeresis          0x1ff
+
+
 #endif //MS Windows System
 
 #ifdef BTRON //BTRON
@@ -724,14 +1199,6 @@
 #define		TK_NU_0		0x2330		/* '0'	*/
 #define		TK_NU_9		0x2339		/* '9'	*/
 
-#define		TK_KK_S		0x2521		/* ʥƬ */
-#define		TK_KK_E 	0x2576		/* ʥʺǸ */
-#define		TK_HK_S 	0x2421		/* Ҥ餬Ƭ */
-#define		TK_HK_E 	0x2473		/* Ҥ餬ʺǸ */
-
-#define		TK_DKON		0x212b		/* 		*/
-#define		TK_HNDK		0x212c		/* Ⱦ	*/
-
 #define		TK_0		(TK_NU_0+0)
 #define		TK_1		(TK_NU_0+1)
 #define		TK_2		(TK_NU_0+2)
